/*
 * Copyright (C) 2020 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

#include <iostream>
#include <gz/plugin/Register.hh>

#include "MultipleQml.hh"

using namespace gz;
using namespace gui;

/////////////////////////////////////////////////
MultipleQml::MultipleQml()
  : Plugin()
{
}

/////////////////////////////////////////////////
MultipleQml::~MultipleQml()
{
}

/////////////////////////////////////////////////
void MultipleQml::OnButton(const QString &_text)
{
  std::cout << _text.toStdString() << std::endl;
}

// Register this plugin
IGNITION_ADD_PLUGIN(MultipleQml,
                    gui::Plugin);
